import "reflect-metadata";
import { TextualMessageEventContent } from "matrix-bot-sdk";
export declare const botCommandSymbol: unique symbol;
export declare function botCommand(options: BotCommandMetadata): void;
export interface BotCommand {
    fn: BotCommandFunction;
    requiredArgs: string[];
    optionalArgs?: string[];
}
export interface BotCommandMetadata {
    help: string;
    name: string;
    requiredArgs: string[];
    optionalArgs?: string[];
}
export interface CommandArguments {
    userId?: string;
    args: string[];
}
export declare type BotCommandFunction = (args: CommandArguments) => Promise<void>;
export declare class BotCommandHandler<T> {
    private readonly instance;
    private readonly prefix?;
    private readonly helpMarkdown;
    private readonly botCommands;
    constructor(prototype: Record<string, BotCommandFunction>, instance: T, prefix?: string | undefined);
    getHelpMessage(cmdPrefix?: string): TextualMessageEventContent;
    /**
     * @param userId The userId who sent the bot command.
     * @param command The command string, including the prefix
     * @param botCommands The set of bot commands in use.
     * @param obj
     * @param prefix
     * @returns True if the command was handled by this handler instance, otherwise false.
     */
    handleCommand(userCommand: string, userId?: string): Promise<boolean>;
}
export declare class BotCommandError extends Error {
    readonly humanText: string;
    constructor(error: Error | string, humanText: string);
}
